bibliotheca Augustana

<<< Übersicht <<< vorige Seite
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 39. Aventiure
___________________________________________________ #### Aventivre wie der herre dieterich #### gventher vnde hagenen betwanch
###### 2324 | ### Do svocht der herre dieterich | selbe sin gewant ### im half daz er sich waffente | meister hildebrant ### do chlagete also sere | der chrepftige man ### daz daz hus erdiezen | von sinen chrepften began
###### 2325 | ### do gewan er wider | rehten heldes mvt ### in grimme wart gewafent | do der helt gvt ### einen schilt vil vesten | nam er an di hant ### si giengn dannen balde | er vnde meister hildebrant
###### 2326 | ### do sprach von tronege hagene | ich sihe dort her gan ### hern dieterichen | der wil vns bestan ### nach sinem starchem leide | daz im ist hi geschehen ### man sol daz hivte chiesen | wem man des besten mvge iehen
###### 2327 | ### ian en dunchet sich von berne | der herre dieterich ### nie so starch des libes | vnd ovch so griwelich ### vnd wilz erz an vns rechen | daz im ist getan ### also redete hagene | ich tar in rehte wol bestan
###### 2328 | ### dise rede horte | dieterich vnd ovh hildebrant ### er chom da er di recken | beide stende vant ### vzen vor dem huse | geleinet an den sal ### sinen schilt den guten | den satzet dieterich ce tal
###### 2329 | ### in leidechlichen sorgen | sprach do dieterich ### wi habt ir so geworben | guenther chuenech rich ### wider mich ellenden | waz het ich iv getan ### alles mines trostes | des pin ich hie eine bestan
###### 2330 | ### ivch en duhte niht der volle | an der grozen not ### do ir vns ruedegeren | den helt sluget tot ### nv habet ir mir erbunnen | aller miner man ### ia ne het ich iv helden | soelher leide niht getan
###### 2331 | ### gedenchet an ivch selben | vnde an iwer leit ### tot der iwern vrivnde | vnd ovch div arbeit ### ob ez iv guten recken | beswaeret iht den mut ### owe wi rehte vnsanpfte | mit tot der rvedgeres tvt
###### 2332 | ### ez geschach ce dirre werlde | nie leider manne mer ### ir gedahtet vebele | an min vnd an iwer ser ### swaz ich frivnde hete | di sint von iv erslagen ### ia ne chan ich nimmer mere | di minen mage verchlagen
###### 2333 | ### ia ne sin wir niht so schvldich | sprach do hagene ### ez giengen zv disem hvse | iwer degene ### gewafent wol ce elize | mit einer schar so breit ### mich dunchet daz div maere | iv niht rehte sin geseit
###### 2334 | ### waz sol ich gelovben maere | mir seitz hildebrant ### do mine recken gerten | von amelvnge lant ### daz ir in rvedgeren | gaebet vz dem sal ### do but ir niwan spotten | den chvenen helden her ce tal
###### 2335 | ### do sprach der kvenech von rine | si iahen wolden tragen ### rvedgeren hinnen | den hiez ich in versagen ### eceln ce leide | vnd niht den dinen man ### vnz daz do wolfhart | darvmbe shelten began
###### 2336 | ### do sprach der helt von berne | ez mvst et also sin ### gventher chvenech edele | dvrch di zvht din ### ergetzze mich der leide | di mir von dir sint geschehen ### vnd svene iz ritter chvene | daz ich des chvenne dir geiehen
###### 2337 | ### ergip dich mir ce gisel | dv vnd ovch din man ### so wil ich behveten | so ih allerbeste chan ### daz dir cen hivnen | niemen niht en tvt ### dv ne solt an mir niht vinden | niwan triwen vnde gvt
###### 2338 | ### daz en welle got von himele | sprah do hagene ### daz sich dir ergaeben | zwene degene ### di noch werliche | gewaffent gegen dir stant ### vnd noch so ledechliche | vor ir vianden gant
###### 2339 | ### ir en svlt iz niht versprechen | so redete dieterich ### gventher vnde hagene | ir habt beide mich ### so ser beswaeret | daz herce vnd ovch den mvt ### welt ir mich ergezzen | daz irz vil pilliche tvt
###### 2340 | ### ich gibe iv mine triwe | vnd sicherliche hant ### daz ich mit iv rite | heim in iwer lant ### ich leit ivch nach den eren | oder ich gelige tot ### vnd wil durch ivch vergezzen | der minen groezlichen not
###### 2341 | ### nv ne muotet sin niht mere | sprach aber hagene ### von vns zimet daz maere | niht wol ce sagene ### daz sich iv ergaeben | zwene also chvene man ### nv siht man bi iv niemen | wan eine hildebranden stan
###### 2342 | ### do sprach meister hildebrant | got weiz her hagene ### der iv den vride bivtet | mit iv ce tragene ### ez chumt noch an di stunde | daz ir moehtet nemen ### di svne mines herren | moht ir iv lazen gezemen
###### 2343 | ### ia naeme ich di svne | sprach aber hagene ### e ich so lasterliche | vze einem gademe ### fluehe meister hildebrant | als ir hie habt getan ### ich waene daz ir chundet | baz gein vianden stan
###### 2344 | ### des antwurte hildebrant | zwiv verwizet ir mir daz ### nv wer was der vf einem schilde | vor dem waskensteine saz ### do im von spanye walther | so uil der frivnde slvch ### ovch habt ir noch ce zeigen | an iv selben genuch
###### 2345 | ### do sprach der herre dieterich | ez en zimt niht helde lip ### daz si svln shelten | sam div alten wip ### ich verbivt iv hildebrant | daz ir niht sprechet mer ### mich ellenden recken | twingent grozlichiv ser
###### 2346 | ### lat horen sprach dieterich | recke hagene ### waz ir beide spraechet | snellen degene ### do ir mich gewafent | zv ziv sahet gan ### ir iahet daz ir eine | mit strite woldet mich bestan
###### 2347 | ### ia ne lovgent iv des niemen | sprach hagen der degen ### ine wellez hie versvchen | mit den starchen slegen ### ez en si daz mir cebreste | daz nibelunges swert ### mir ist zorn daz vnser beider | ist ce gisel hie gegert
###### 2348 | ### do dieterich gehorte | den grimmen hagenen mvt ### den schilt vil balde zvchte | der snelle degn gvt ### wi balde gein im hagene | von der stiege spranch ### niblvnges swert daz gvte | vil lvt vf dieteriche erchlanch
###### 2349 | ### do wesse wol her dieterich | daz der chvene man ### vil grimmes mvtes waere | schermen im began ### der herre von berne | vor angestlichen slegen ### wol erchand er hagenen | den vil zierlichen degen
###### 2350 | ### ovch vorht er balmungen | ein wafen starch genvch ### vnder wilen dietrich | mit listen widerslvch ### vnz daz er hagenen | mit strite doch betwanch ### er slvch im eine wunden | div was tief vnde lanch
###### 2351 | ### do daht der herre dietrich | dv bist in noeten erwigen ### ich hans lvecel ere | soltv tot vor mir geligen ### ich wilz sus versvchen | ob ich ertwingen chan ### dich mir ce einem gisel | daz wart mit sorgen getan
###### 2352 | ### den schilt den liez er vallen | sin sterche div was groz ### hagenen von tronege | mit armen er besloz ### des wart do betwungen | von im der chvene man ### gventher der edele | darvmbe trvoren began
###### 2353 | ### hagenen bant dieterich | vnd fvrt in da er vant ### di edeln kveneginne | vnd gab ir bi der hant ### den chvenesten recken | der ie swert getrvch ### nach ir vil starchem leide | do wart si vroelich genvch
###### 2354 | ### vor liebe neich dem degene | daz eceln wip ### immer si dir saelich | din herce vnd ovch der lip ### dv hast mich wol ergezzet | aller miner not ### daz sol ich immer dienen | mich en svme danne der tot
###### 2355 | ### do sprach der herre dietrich | ir svlt in lan genesen ### edliv chveneginne | vnd mach daz noch gewesen ### wi wol er ivch ergezzet | daz er iv hat getan ### ern sol des niht engelten | daz ir in seht gebvnden stan
###### 2356 | ### do hiez si hagenen fveren | an sin vngemach ### da er lach beslozen | vnt da niemen sach ### gventher der kvenech edele | rveffen do began ### war chom der helt von berne | der hat mir leide getan
###### 2357 | ### do gie im hin engegene | der herre dietrich ### daz gventheres ellen | daz was vil loblich ### do ne beit ovch er niht mere | er lief her fver den sal ### von ir beider swerten | huop sich ein groezlicher shal
###### 2358 | ### swi vil der herre dietrich | lange was gelobt ### gventher was so ser | erzvernet vnd ertobt ### wand er nach starchem leide | sin herce vient was ### man sagt ez noch ce wunder | daz do her dietrich genas
###### 2359 | ### ir ellen vnd ir sterche | beider waren groz ### palas vnd tvrne | von den slegen doz ### do si mit swerten hiwen | vf die helme gvt ### ez het der kvenech gventher | einen herlichen mvt
###### 2360 | ### sit twang in der von berne | sam hagenen e geschach ### daz plvot man dvrch di ringe | dem helde vliezen sach ### von einem sharpfen swerte | daz trvch dietrich ### do het gewert her gventher | nach mvede lobeliche sich
###### 2361 | ### der herre wart gebvnden | von dietriches hant ### swi chvenege nine solden | liden solhiv bant ### er daht ob er si lieze | den kvenech vnde sinen man ### alle di si fvenden | di mvesen tot von in bestan
###### 2362 | ### dieterich von berne | der nam in bi der hant ### do fvrt er in gebunden | da er criemhilde vant ### do was mit sinem leide | ir sorgen vil erwant ### si sprach willechom gventher | vzer bvrgonden lant
###### 2363 | ### er sprach ich sol iv nigen | vil liebiv swester min ### ob iwer grvezen moehte | genaedechlicher sin ### ich weiz ivch kveneginne | so zornech gemvt ### daz ir mich vnde hagenen | vil swache grvezen getvt
###### 2364 | ### do sprach der helt von berne | vil edeles chveneges wip ### ez en wart gisel mere | so guter ritter lip ### als ich vrowe here | iv an in gegebn han ### nv svlt ir di ellenden | min vil wol geniezen lan
###### 2365 | ### si iach si taet iz gerne | do gi her dieterich ### mit weinenden ovgen | von den helden lobelich ### sit rach sich grimmechlichen | daz eceln wip ### den vzerwelten degenen | nam si beiden den lip
###### 2366 | ### sie lie si ligen besvnder | dvrch ir vngemach ### daz ir sit deweder | den andern ni gesach ### vnz si ir brvder hovbet | hin fver hagenen trvch ### der criemhilde rache | wart an in beiden genvch
###### 2367 | ### do gie div chvneginne | da si hagenen sach ### wi rehte fientliche | si zv dem helde sprach ### welt ir mir geben wider | daz ir mir habt genomen ### so mvget ir wol lebende | heim cen bvrgonden chomen
###### 2368 | ### do sprach der grimme hagene | div rede ist gar verlorn ### vil edliv chveneginne | ia han ich des gesworn ### daz ich den hort iht zeige | di wile daz si leben ### deheiner miner herren | so sol ich in niemene geben
###### 2369 | ### ich bringez an ein ende | so sprah daz edel wip ### do hiez si ir bruder | nemen sinen vil shonen lip ### slvch im ab daz hovbet | bi dem hare si ez trvch ### fver den helt von tronege | do wart im leide genvch
###### 2370 | ### also der vngemvote | sines herren hovbet sach ### wider criemhilde | do der recke sprach ### dv hast iz nach dinem willen | vil gar zeinem ende braht ### vnd ist ovch iv ergangen | als ich mir het gedaht
###### 2371 | ### nv ist von bvrgonden | der edel kvenech tot ### giselher der ivnge | vnde ovch her gernot ### den shaz den weiz nv niemen | wan got ane min ### der sol dich valendinne | immer verborgen sin
###### 2372 | ### si sprach so habt ir vebele | geltes mich gewert ### so wil ich doch behalten | daz sifrides swert ### daz truch min holder vriedel | do ich in ivngest sach ### an dem mir herceleide | von iwern shvlden geschach
###### 2373 | ### si zoh iz von der scheiden | daz chvnd er niht erwern ### do daht si den recken | des libes wol behern ### si hvb im vf daz hovbt | mit dem swerte siz ab slvch ### daz sach der kvenech ecel | do was im leide genvch
###### 2374 | ### waffen sprach der fverste | wi ist nv tot gelegen ### von eines wibes handen | der allerbeste degen ### der ie chom ce stvrme | oder ie schilt getrvch ### swi vient ich im waere | ez ist mir leide genvch
###### 2375 | ### do sprach der alte hildebrant | ia genivzet si des niht ### daz si in slahen torste | swaz mir davon gesrhit ### swi er mich selbe braehte | in angestliche not ### idoh so wil ich recken | des chvenen tronegaeres tot
###### 2376 | ### hildebrant mit zorne | zv creimhilde spranch ### er slvch der chveneginne | einen swaeren swert swanch ### ia tet ir div sorge | von hildebrande we ### waz mohte si gehelffen | daz si groezlichen shre
###### 2377 | ### do was gelenget aller | da der veigen lip ### ze stvcken was gehowen | do daz edele wip ### dieterich vnd ecel | weinen do began ### si chlagten innechliche | beide mage vnd man
###### 2378 | ### div vil michel ere | was gelegen tot ### di livte heten alle | iamer vnde not ### mit leide was verendet | des kvenges hohgezit ### als ie div liebe leide | zaller ivngeste git
###### 2379 | ### ine chan iv niht bescheiden | waz sider da geschach ### wan ritter vnd vrowen | weinen man da sach ### darzv di edeln knehte | ir lieben frivnde tot ### da hat daz maere ein ende | diz ist der nibelunge not

<<< Übersicht <<< vorige Seite